
Welcome to pytest-houdini's documentation!
==========================================

This `pytest <http://pytest.org>`_ plugin provides a number of fixtures and utilities for use with testing code run by
`SideFX's Houdini <http://sidefx.com>`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   fixtures/index.rst
   tools
